##  Dashboard Structure
By default, the dashboard consists of the following areas:
  * Welcome message and overview of learnings/resources
  * Overview of personal Application Portfolio by attributes
  * Overview of action items for collaboration in SAP LeanIX
  * Advanced use: Overview of Application Landscape


### Enablement Content
By default, the onboarding dashboard provides links to the SAP LeanIX product documentation for Application and Business Owners. These resources assist users in navigating the workspace and taking their initial steps in using SAP LeanIX during the onboarding process, including:
  * What is SAP LeanIX and the value of Enterprise Architecture
  * How to fill an Application Fact Sheet
  * How to maintain data with Quality Seals and continuous updates


You can further add links to internal resources and relevant content available in your organization.
![Enablement Content in the Onboarding Dashboard](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757a93f7a441014bb29f7ff118486cf_LowRes.png)
Enablement Content in the Onboarding Dashboard
### Overview of Personal Application Portfolio
Each Fact Sheet Chart in this section displays the current status of the Application Portfolio, filtered based on the Fact Sheets the user has subscriptions to. Clicking on the columns leads to the inventory, to the list of Application Fact Sheets filtered by the corresponding attribute of the column.
  * My Fact Sheets: Shows the list of all subscribed Fact Sheets. Clicking the link leads to the inventory, to the list of Application Fact Sheets filtered by subscription of the respective user.
  * Applications with Quality Seal Approved / Business Criticality / Lifecycle / Functional Fit / Technical Fit: Each Fact Sheet Chart visualizes the number of Applications filtered by relevant attributes for the respective user. This helps in analyzing the application portfolio at a glance. For example, if you want to know how many of your Applications are mission critical, the Fact Sheet Chart on Business Criticality gives you that information. While the columns ‘n/a’ give information on Application Fact Sheets that have missing information, helping you easily identify Fact Sheets with missing attributes.
  * Which Business Capabilities are supported by my Applications?: Shows the number of Applications filtered by Business Capabilities for the respective user. This provides a quick understanding of the key business functionalities and activities supported by the user's application portfolio.
  * Which Organizations are supported by my Applications?: Shows the number of Applications filtered by Organizations for the respective user. This provides a quick understanding of which organizational groups and entities use the user's application portfolio.


![Overview of Personal Application Portfolio](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275425737a4410149682fedf7a586e82_LowRes.png)
Overview of Personal Application Portfolio
### Overview of Action Items
This section focuses on collaboration and action items in the workspace. It shows a summary of Surveys and To-Dos that are assigned to the respective user. By clicking on the action items, the user is directed to the respective page and task.
![Overview of Action Items](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27457c9b7a44101499fc88f9e237a947_LowRes.png)
Overview of Action Items
### Overview of Application Landscape
This section presents the Application Landscape report, offering a holistic view of your organization's IT landscape. It helps users understand how the applications support various business capabilities and provides a color-coded overview of application lifecycle information. You can also add other relevant reports and panels as per your needs
![Overview of Application Landscape](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27497d9e7a44101485259c98d7c38024_LowRes.png)
Overview of Application Landscape
YesNo
Send
